@@ -6,16 +6,7 @@ from ...base.tool import BaseAction
 
 name = "azure_devops_wiki"
 
-def get_tools(tool):
-    return AzureDevOpsToolkit().get_toolkit(
-        selected_tools=tool['settings'].get('selected_tools', []),
-        organization_url=tool['settings']['organization_url'],
-        project=tool['settings'].get('project', None),
-        token=tool['settings'].get('token', None),
-    ).get_tools()
-
-
-class AzureDevOpsToolkit(BaseToolkit):
+class AzureDevOpsWikiToolkit(BaseToolkit):
     tools: List[BaseTool] = []
 
     @classmethod
