@@ -6,17 +6,7 @@ from ...base.tool import BaseAction
 
 name = "azure_devops_boards"
 
-def get_tools(tool):
-    return AzureDevOpsToolkit().get_toolkit(
-        selected_tools=tool['settings'].get('selected_tools', []),
-        organization_url=tool['settings']['organization_url'],
-        project=tool['settings'].get('project', None),
-        token=tool['settings'].get('token', None),
-        limit=tool['settings'].get('limit', 5),
-    ).get_tools()
-
-
-class AzureDevOpsToolkit(BaseToolkit):
+class AzureDevOpsWorkItemsToolkit(BaseToolkit):
     tools: List[BaseTool] = []
 
     @classmethod
@@ -26,6 +16,7 @@ class AzureDevOpsToolkit(BaseToolkit):
             environ['AZURE_DEVOPS_CACHE_DIR'] = '/tmp/.azure-devops'
         if selected_tools is None:
             selected_tools = []
+
         azure_devops_api_wrapper = AzureDevOpsApiWrapper(**kwargs)
         available_tools = azure_devops_api_wrapper.get_available_tools()
         tools = []
